@@ -30,7 +30,7 @@ class BaseProvider:
     def map_profile_data(self, data):
         raise NotImplementedError('map profile data')
 
-    def process_login(self, name, social_id, email='', phone=''):
+    def process_login(self, name, social_id, email='', phone='', **kwargs):
         profile = self.profile_class.objects.filter(provider=self.provider, social_id=social_id)
         if not profile:
             user = User.objects.create_user(username=uuid4().__str__())
@@ -45,9 +45,7 @@ class BaseProvider:
         profile_data = self.get_profile(token)
         mapped = self.map_profile_data(profile_data)
         profile = self.process_login(**mapped)
-        handler = self.handler_class()
-        result = handler.on_login_success(profile)
-        return result
+        return profile
 
     def get_avatar(self, **data):
         raise NotImplementedError
